package awais.instagrabber.models;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import awais.instagrabber.utils.Utils;

public final class CommentModel {
    private final static SimpleDateFormat DATETIME_PARSER;
    static {
        DATETIME_PARSER = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss", Locale.getDefault());
    }
    private final ProfileModel profileModel;
    private final String id, dateTime;
    private final CharSequence text;
    private final long likes;
    private CommentModel[] childCommentModels;
    private boolean hasNextPage;
    private String endCursor;

    public CommentModel(final String id, final String text, final long timestamp, final long likes, final ProfileModel profileModel) {
        this.id = id;

        final boolean hasMentions = text != null && (text.contains("@") || text.contains("#"));
        this.text = hasMentions ? Utils.getMentionText(text) : text;

        this.likes = likes;
        this.profileModel = profileModel;
        this.dateTime = DATETIME_PARSER.format(new Date(timestamp * 1000L));
    }

    public String getId() {
        return id;
    }

    public CharSequence getText() {
        return text;
    }

    public String getDateTime() {
        return dateTime;
    }

    public long getLikes() {
        return likes;
    }

    public ProfileModel getProfileModel() {
        return profileModel;
    }

    public CommentModel[] getChildCommentModels() {
        return childCommentModels;
    }

    public void setChildCommentModels(final CommentModel[] childCommentModels) {
        this.childCommentModels = childCommentModels;
    }

    public void setPageCursor(final boolean hasNextPage, final String endCursor) {
        this.hasNextPage = hasNextPage;
        this.endCursor = endCursor;
    }

    public boolean hasNextPage() {
        return hasNextPage;
    }

    public String getEndCursor() {
        return endCursor;
    }

//    @NonNull
//    @Override
//    public String toString() {
//        try {
//            final JSONObject object = new JSONObject();
//            object.put("id", id);
//            object.put("text", text);
//            object.put("name", profileModel != null ? profileModel.getUsername() : "");
//            if (childCommentModels != null) object.put("childComments", childCommentModels);
//            return object.toString();
//        } catch (Exception e) {
//            return "{\"id\":\"" + id + "\", \"text\":\"" + text
//                     //(text != null ? text.replaceAll("\"", "\\\\\"") : "")
//                    + "\", \"name\":\"" + (profileModel != null ? profileModel.getUsername() : "") +
//                    (childCommentModels != null ? "\", \"childComments\":" + childCommentModels.length : "\"") + '}';
//        }
//    }
}